@@ -22,7 +22,7 @@ solana_program::declare_id!("ide3Y2TubNMLLhiG1kDL6to4a8SjxD18YWCYC5BZqNV");
 
 /// Given a DID, validate that the signers contain at least one
 /// account that has permissions to sign transactions using the DID.
-pub fn validate_owner(did: &AccountInfo, signers: &[AccountInfo]) -> ProgramResult {
+pub fn validate_owner(did: &AccountInfo, signers: &[&AccountInfo]) -> ProgramResult {
     if did.owner.ne(&id()) {
         return Err(ProgramError::IncorrectProgramId);
     }
