@@ -1,9 +1,6 @@
 // Mark this test as BPF-only due to current `ProgramTest` limitations when CPIing into the system program
 #![cfg(feature = "test-bpf")]
 
-use solana_program_test::tokio;
-use solana_sdk::account::Account;
-use solana_sdk::program_error::ProgramError;
 use {
     borsh::BorshSerialize,
     sol_did::{
@@ -22,9 +19,11 @@ use {
         pubkey::Pubkey,
         rent::Rent,
     },
-    solana_program_test::{processor, ProgramTest, ProgramTestContext},
+    solana_program_test::{processor, tokio, ProgramTest, ProgramTestContext},
     solana_sdk::{
+        account::Account,
         account_info::IntoAccountInfo,
+        program_error::ProgramError,
         signature::{Keypair, Signer},
         transaction::{Transaction, TransactionError},
         transport,
@@ -184,7 +183,7 @@ async fn initialize_too_small_fail() {
         .unwrap();
     assert_eq!(
         err,
-        TransactionError::InstructionError(0, InstructionError::InvalidError)
+        TransactionError::InstructionError(0, InstructionError::BorshIoError("Unkown".to_string())),
     );
 }
 
@@ -497,7 +496,7 @@ async fn validate_owner_success() {
     let authority_key = &authority.pubkey();
     let authority_account_info = (authority_key, true, &mut empty_account).into_account_info();
 
-    let validation_result = validate_owner(&sol_account_info, &[authority_account_info]);
+    let validation_result = validate_owner(&sol_account_info, &[&authority_account_info]);
     assert_eq!(validation_result, Ok(()));
 }
 
@@ -512,7 +511,7 @@ async fn validate_owner_failed_non_signer() {
     // pass the authority, but not as a signer
     let authority_account_info = (authority_key, false, &mut empty_account).into_account_info();
 
-    let validation_result = validate_owner(&sol_account_info, &[authority_account_info]);
+    let validation_result = validate_owner(&sol_account_info, &[&authority_account_info]);
     assert_eq!(validation_result, Err(ProgramError::Custom(0))) // IncorrectAuthority
 }
 
@@ -531,7 +530,7 @@ async fn validate_owner_failed_not_did() {
     let authority_key = &authority.pubkey();
     let authority_account_info = (authority_key, true, &mut empty_account).into_account_info();
 
-    let validation_result = validate_owner(&sol_account_info, &[authority_account_info]);
+    let validation_result = validate_owner(&sol_account_info, &[&authority_account_info]);
     assert_eq!(validation_result, Err(ProgramError::IncorrectProgramId))
 }
 
